@@ -1,3 +1,4 @@
+from __future__ import print_function, absolute_import, division
 from osprey.entry_point import load_entry_point
 from nose.tools import assert_raises
 
@@ -18,8 +19,7 @@ def test_3():
 
 
 def test_4():
-    with assert_raises(RuntimeError):
-        load_entry_point('sklearn')
-
-    with assert_raises(RuntimeError):
-        load_entry_point('sklearn.sdsdfjhgdsf')
+    assert_raises(RuntimeError,
+                  lambda: load_entry_point('sklearn'))
+    assert_raises(RuntimeError,
+                  lambda: load_entry_point('sklearn.sdsdfjhgdsf'))
